<?php
/**
 * Plugin Name: Sassnex Elementor
 * Description: Create unlimited widgets with Elementor Page Builder.
 * Plugin URI:  http://shtheme.com/
 * Version:     1.0.0
 * Author:      Nasir Uddin Mandal
 * Author URI:  http://shtheme.com
 * Text Domain: bdevs-elementor
 * Domain Path: /languages/
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Main Bdevs Elementor Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */
final class BdevsElementor {

	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '5.5';

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var BdevsElementor The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return BdevsElementor An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {

		add_action( 'init', [ $this, 'i18n' ] );
		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}

	/**
	 * Load Textdomain
	 *
	 * Load plugin localization files.
	 *
	 * Fired by `init` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function i18n() {

		load_plugin_textdomain( 'bdevs-elementor' );

	}

	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}

		add_action( 'elementor/init', [ $this, 'add_elementor_category' ], 1 );

		// Add Plugin actions
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'register_frontend_scripts' ], 10 );

		// Register Widget Styles
		add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'register_frontend_styles' ] );

		add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );

		// Register controls
		//add_action( 'elementor/controls/controls_registered', [ $this, 'register_controls' ] );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'bdevs-elementor' ),
			'<strong>' . esc_html__( 'Sassnex Elementor', 'bdevs-elementor' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'bdevs-elementor' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bdevs-elementor' ),
			'<strong>' . esc_html__( 'Sassnex Elementor', 'bdevs-elementor' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'bdevs-elementor' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bdevs-elementor' ),
			'<strong>' . esc_html__( 'Sassnex Elementor', 'bdevs-elementor' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'bdevs-elementor' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Add Elementor category.
	 */
	public function add_elementor_category() {
    	\Elementor\Plugin::instance()->elements_manager->add_category('bdevs-elementor',
	      	array(
					'title' => __( 'Sassnex Elementor', 'bdevs-elementor' ),
					'icon'  => 'fa fa-plug',
	      	) 
	    );
	}

	/**
	* Register Frontend Scripts
	*
	*/
	public function register_frontend_scripts() {
	wp_register_script( 'bdevs-elementor', plugin_dir_url( __FILE__ ) . 'assets/js/bdevs-elementor.js', array( 'jquery' ), self::VERSION );
	}


	/**
	* Register Frontend styles
	*
	*/
	public function register_frontend_styles() {
	wp_register_style( 'bdevs-elementor', plugin_dir_url( __FILE__ ) . 'assets/css/bdevs-elementor.css', self::VERSION );
	}




	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init_widgets() { 

		// Include Widget files
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/features.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home2-productlanding/features1.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/intro-home1.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home2-productlanding/intro-home2.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/intro-home3.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/intro-home4.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home5-digitalmarketing/intro-home5.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/intro-home6.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/service-app.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home2-productlanding/service-product.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/download-app.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/download-count.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/team.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home5-digitalmarketing/team-marketing.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/intro-team.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/our-team.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/client-logo.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/free-trail.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/free-trail-home.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/free-trail-home1.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/app-screenshort.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home1-applanding/testimonial.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home2-productlanding/testimonial1.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/testimonial2.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home5-digitalmarketing/testimonial3.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/testimonial4.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/blog-widget.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home2-productlanding/video-product.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/product-special.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/agency-services.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/video-agency.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/count-lead.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/agency-project.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/team-agency.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/agency-testimonial.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/agency-blog.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home3-startupagency/need-help.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home5-digitalmarketing/need-help1.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/start-services.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/automation.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/earnings-grow.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/prycing-table.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home4-paymentprocessing/video-payment.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home5-digitalmarketing/service-section.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home5-digitalmarketing/marketing-features.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/sass-services.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/sass-features.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/tools-sass.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/sass-application.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/home6-sasslanding/secured-section.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/secured-section1.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/intro-page.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/our-mission.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/our-vission.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/team-vission.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/contact-form.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/location.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/page-team/pricing-packages.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/login.php';
		require_once plugin_dir_path( __FILE__ ) . 'widgets/singup.php';





		// Register widget
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsFeatures() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsFeatures1() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroHome1() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroHome2() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroHome3() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroHome4() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroHome5() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroHome6() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsServiceApp() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsServiceProduct() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsDownloadApp() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsDownloadCount() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTeam() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTeamMarketing() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroTeam() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsOurTeam() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsClientLogo() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsFreeTrail() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsFreeTrailHome() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsFreeTrailHome1() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsAppScreenshort() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTestimonial() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTestimonial1() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTestimonial2() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTestimonial3() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTestimonial4() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsBlogWidget() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsVideoProduct() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsProductSpecial() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsAgencyServices() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsVideoAgency() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsCountLead() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsAgencyProject() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTeamAgency() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsAgencyTestimonial() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsAgencyBlog() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsNeedHelp() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsNeedHelp1() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsStartServices() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsAutomation() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsEarningsGrow() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsPrycingTable() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsVideoPayment() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsServiceSection() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsMarketingFeatures() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsSassServices() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsSassFeatures() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsToolSass() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsSassApplication() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsSecuredSection() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsSecuredSection1() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsIntroPage() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsOurMission() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsOurVission() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsTeamVission() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsContactForm() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsLocation() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsPricingPackages() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsLogin() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \BdevsElementor\Widget\BdevsSingup() );






	}

	/** 
	 * register_controls description
	 * @return [type] [description]
	 */
	public function register_controls() {

		$controls_manager = \Elementor\Plugin::$instance->controls_manager;
		$controls_manager->register_control( 'slider-widget', new Test_Control1() );
	
	}

	/**
	 * Prints the Elementor Page content.
	 */
	public static function get_content( $id = 0 ) {
		if ( class_exists( '\ElementorPro\Plugin' ) ) {
			echo do_shortcode( '[elementor-template id="' . $id . '"]' );
		} else {
			echo \Elementor\Plugin::instance()->frontend->get_builder_content_for_display( $id );
		}
	}

}

BdevsElementor::instance();
